==> winmd-1.0.0-pre.13.tar.gz: lib/src/memberref.dart <==
// Copyright (c) 2020, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:ffi';
import 'dart:typed_data';

import 'package:ffi/ffi.dart';
import 'package:win32/win32.dart';

import 'base.dart';
import 'scope.dart';
import 'type_aliases.dart';

/// A member reference.
///
/// This class is used to declare a reference to a field or method which is
/// defined in another module or assembly. It represents either a `MethodRef` or
/// a `FieldRef`.
class MemberRef extends TokenObject {
  final String name;
  final Uint8List signatureBlob;

  const MemberRef(Scope scope, int token, this.name, this.signatureBlob)
      : super(scope, token);

  /// Creates a module object from its given token.
  factory MemberRef.fromToken(Scope scope, int token) {
    final ptk = calloc<mdToken>();
    final szMember = wsalloc(MAX_STRING_SIZE);
    final pchMember = calloc<ULONG>();
    final ppvSigBlob = calloc<PCCOR_SIGNATURE>();
    final pcbSigBlob = calloc<ULONG>();

    try {
      final reader = scope.reader;
      final hr = reader.GetMemberRefProps(token, ptk, szMember, MAX_STRING_SIZE,
          pchMember, ppvSigBlob, pcbSigBlob);

      if (SUCCEEDED(hr)) {
        return MemberRef(scope, ptk.value, szMember.toDartString(),
            ppvSigBlob.value.asTypedList(pcbSigBlob.value));
      } else {
        throw WindowsException(hr);
      }
    } finally {
      free(ptk);
      free(szMember);
      free(pchMember);
      free(ppvSigBlob);
      free(pcbSigBlob);
    }
  }

  @override
  String toString() => name;
}

==> winmd-1.0.5.tar.gz: lib/src/memberref.dart <==
// Copyright (c) 2020, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

import 'dart:ffi';
import 'dart:typed_data';

import 'package:ffi/ffi.dart';
import 'package:win32/win32.dart';

import 'base.dart';
import 'scope.dart';
import 'type_aliases.dart';

/// A member reference.
///
/// This class is used to declare a reference to a field or method which is
/// defined in another module or assembly. It represents either a `MethodRef` or
/// a `FieldRef`.
class MemberRef extends TokenObject {
  final String name;
  final Uint8List signatureBlob;

  const MemberRef(Scope scope, int token, this.name, this.signatureBlob)
      : super(scope, token);

  /// Creates a module object from a provided token.
  factory MemberRef.fromToken(Scope scope, int token) {
    final ptk = calloc<mdToken>();
    final szMember = wsalloc(MAX_STRING_SIZE);
    final pchMember = calloc<ULONG>();
    final ppvSigBlob = calloc<PCCOR_SIGNATURE>();
    final pcbSigBlob = calloc<ULONG>();

    try {
      final reader = scope.reader;
      final hr = reader.GetMemberRefProps(token, ptk, szMember, MAX_STRING_SIZE,
          pchMember, ppvSigBlob, pcbSigBlob);

      if (SUCCEEDED(hr)) {
        return MemberRef(scope, ptk.value, szMember.toDartString(),
            ppvSigBlob.value.asTypedList(pcbSigBlob.value));
      } else {
        throw WindowsException(hr);
      }
    } finally {
      free(ptk);
      free(szMember);
      free(pchMember);
      free(ppvSigBlob);
      free(pcbSigBlob);
    }
  }

  @override
  String toString() => name;
}
